pub fn scan(
recognizers: &[Box<dyn Recognizer>],
config: &Config,
options: &ScanOptions,
) -> ScanResultExpand description
Run all enabled recognizers in parallel and collect findings.
pub fn scan(
recognizers: &[Box<dyn Recognizer>],
config: &Config,
options: &ScanOptions,
) -> ScanResultRun all enabled recognizers in parallel and collect findings.